@@ -30,26 +30,26 @@
 #include <unistd.h>
 #include <pwd.h>
 #include <sys/param.h>
+#include <errno.h>
 
 // Qt
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QFlags>
-#include <QtCore/QTextStream>
-#include <QtCore/QStringList>
-#include <QtNetwork/QHostInfo>
+#include <QDir>
+#include <QFileInfo>
+#include <QFlags>
+#include <QTextStream>
+#include <QStringList>
+#include <QHostInfo>
 
 // KDE
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KUser>
-#include <QDebug>
 
-#if defined(Q_OS_FREEBSD) || defined(Q_OS_OPENBSD) || defined(Q_OS_OSX)
+#if defined(Q_OS_FREEBSD) || defined(Q_OS_OPENBSD) || defined(Q_OS_MACOS)
 #include <sys/sysctl.h>
 #endif
 
-#if defined(Q_OS_OSX)
+#if defined(Q_OS_MACOS)
 #include <libproc.h>
 #include <qplatformdefs.h>
 #endif
@@ -62,27 +62,30 @@
 #   include <libutil.h>
 #   include <sys/param.h>
 #   include <sys/queue.h>
-#   include <libprocstat.h>
 #   endif
 #endif
 
 using namespace Konsole;
 
-ProcessInfo::ProcessInfo(int aPid)
-    : _fields(ARGUMENTS)   // arguments
+ProcessInfo::ProcessInfo(int aPid) :
+    _fields(ARGUMENTS)     // arguments
     // are currently always valid,
     // they just return an empty
     // vector / map respectively
     // if no arguments
     // have been explicitly set
-    , _pid(aPid)
-    , _parentPid(0)
-    , _foregroundPid(0)
-    , _userId(0)
-    , _lastError(NoError)
-    , _userName(QString())
-    , _userHomeDir(QString())
-    , _userNameRequired(true)
+    ,
+    _pid(aPid),
+    _parentPid(0),
+    _foregroundPid(0),
+    _userId(0),
+    _lastError(NoError),
+    _name(QString()),
+    _userName(QString()),
+    _userHomeDir(QString()),
+    _currentDir(QString()),
+    _userNameRequired(true),
+    _arguments(QVector<QString>())
 {
 }
 
@@ -90,6 +93,7 @@ ProcessInfo::Error ProcessInfo::error() const
 {
     return _lastError;
 }
+
 void ProcessInfo::setError(Error error)
 {
     _lastError = error;
@@ -109,8 +113,7 @@ QString ProcessInfo::validCurrentDir() const
     int currentPid = parentPid(&ok);
     QString dir = currentDir(&ok);
     while (!ok && currentPid != 0) {
-        QString tmp = QString("");
-        ProcessInfo* current = ProcessInfo::newInstance(currentPid, tmp);
+        ProcessInfo *current = ProcessInfo::newInstance(currentPid, QString());
         current->update();
         currentPid = current->parentPid(&ok);
         dir = current->currentDir(&ok);
@@ -127,8 +130,8 @@ QSet<QString> ProcessInfo::commonDirNames()
     static bool forTheFirstTime = true;
 
     if (forTheFirstTime) {
-        const KSharedConfigPtr& config = KSharedConfig::openConfig();
-        const KConfigGroup& configGroup = config->group("ProcessInfo");
+        const KSharedConfigPtr &config = KSharedConfig::openConfig();
+        const KConfigGroup &configGroup = config->group("ProcessInfo");
         _commonDirNames = QSet<QString>::fromList(configGroup.readEntry("CommonDirNames", QStringList()));
 
         forTheFirstTime = false;
@@ -137,11 +140,11 @@ QSet<QString> ProcessInfo::commonDirNames()
     return _commonDirNames;
 }
 
-QString ProcessInfo::formatShortDir(const QString& input) const
+QString ProcessInfo::formatShortDir(const QString &input) const
 {
     QString result;
 
-    const QStringList& parts = input.split(QDir::separator());
+    const QStringList &parts = input.split(QDir::separator());
 
     QSet<QString> dirNamesToShorten = commonDirNames();
 
@@ -153,7 +156,7 @@ QString ProcessInfo::formatShortDir(const QString& input) const
     // and stopping when we reach a dir name which is not
     // in the commonDirNames set
     while (iter.hasPrevious()) {
-        const QString& part = iter.previous();
+        const QString &part = iter.previous();
 
         if (dirNamesToShorten.contains(part)) {
             result.prepend(QDir::separator() + part[0]);
@@ -166,7 +169,7 @@ QString ProcessInfo::formatShortDir(const QString& input) const
     return result;
 }
 
-QVector<QString> ProcessInfo::arguments(bool* ok) const
+QVector<QString> ProcessInfo::arguments(bool *ok) const
 {
     *ok = _fields.testFlag(ARGUMENTS);
 
@@ -178,35 +181,35 @@ bool ProcessInfo::isValid() const
     return _fields.testFlag(PROCESS_ID);
 }
 
-int ProcessInfo::pid(bool* ok) const
+int ProcessInfo::pid(bool *ok) const
 {
     *ok = _fields.testFlag(PROCESS_ID);
 
     return _pid;
 }
 
-int ProcessInfo::parentPid(bool* ok) const
+int ProcessInfo::parentPid(bool *ok) const
 {
     *ok = _fields.testFlag(PARENT_PID);
 
     return _parentPid;
 }
 
-int ProcessInfo::foregroundPid(bool* ok) const
+int ProcessInfo::foregroundPid(bool *ok) const
 {
     *ok = _fields.testFlag(FOREGROUND_PID);
 
     return _foregroundPid;
 }
 
-QString ProcessInfo::name(bool* ok) const
+QString ProcessInfo::name(bool *ok) const
 {
     *ok = _fields.testFlag(NAME);
 
     return _name;
 }
 
-int ProcessInfo::userId(bool* ok) const
+int ProcessInfo::userId(bool *ok) const
 {
     *ok = _fields.testFlag(UID);
 
@@ -240,7 +243,7 @@ void ProcessInfo::setUserId(int uid)
     _fields |= UID;
 }
 
-void ProcessInfo::setUserName(const QString& name)
+void ProcessInfo::setUserName(const QString &name)
 {
     _userName = name;
     setUserHomeDir();
@@ -248,11 +251,12 @@ void ProcessInfo::setUserName(const QString& name)
 
 void ProcessInfo::setUserHomeDir()
 {
-    const QString& usersName = userName();
-    if (!usersName.isEmpty())
+    const QString &usersName = userName();
+    if (!usersName.isEmpty()) {
         _userHomeDir = KUser(usersName).homeDir();
-    else
+    } else {
         _userHomeDir = QDir::homePath();
+    }
 }
 
 void ProcessInfo::setParentPid(int aPid)
@@ -260,6 +264,7 @@ void ProcessInfo::setParentPid(int aPid)
     _parentPid = aPid;
     _fields |= PARENT_PID;
 }
+
 void ProcessInfo::setForegroundPid(int aPid)
 {
     _foregroundPid = aPid;
@@ -276,25 +281,28 @@ bool ProcessInfo::userNameRequired() const
     return _userNameRequired;
 }
 
-QString ProcessInfo::currentDir(bool* ok) const
+QString ProcessInfo::currentDir(bool *ok) const
 {
-    if (ok)
-        *ok = _fields & CURRENT_DIR;
+    if (ok != nullptr) {
+        *ok = (_fields & CURRENT_DIR) != 0;
+    }
 
     return _currentDir;
 }
-void ProcessInfo::setCurrentDir(const QString& dir)
+
+void ProcessInfo::setCurrentDir(const QString &dir)
 {
     _fields |= CURRENT_DIR;
     _currentDir = dir;
 }
 
-void ProcessInfo::setName(const QString& name)
+void ProcessInfo::setName(const QString &name)
 {
     _name = name;
     _fields |= NAME;
 }
-void ProcessInfo::addArgument(const QString& argument)
+
+void ProcessInfo::addArgument(const QString &argument)
 {
     _arguments << argument;
 }
@@ -323,14 +331,13 @@ void ProcessInfo::setFileError(QFile::FileError error)
 // implementations of the UnixProcessInfo abstract class.
 //
 
-NullProcessInfo::NullProcessInfo(int aPid, const QString& /*titleFormat*/)
-    : ProcessInfo(aPid)
+NullProcessInfo::NullProcessInfo(int aPid, const QString & /*titleFormat*/) :
+    ProcessInfo(aPid)
 {
 }
 
-bool NullProcessInfo::readProcessInfo(int /*pid*/)
+void NullProcessInfo::readProcessInfo(int /*pid*/)
 {
-    return false;
 }
 
 bool NullProcessInfo::readCurrentDir(int /*pid*/)
@@ -343,66 +350,71 @@ void NullProcessInfo::readUserName()
 }
 
 #if !defined(Q_OS_WIN)
-UnixProcessInfo::UnixProcessInfo(int aPid, const QString& titleFormat)
-    : ProcessInfo(aPid)
+UnixProcessInfo::UnixProcessInfo(int aPid, const QString &titleFormat) :
+    ProcessInfo(aPid)
 {
     setUserNameRequired(titleFormat.contains(QLatin1String("%u")));
 }
 
-bool UnixProcessInfo::readProcessInfo(int aPid)
+void UnixProcessInfo::readProcessInfo(int aPid)
 {
     // prevent _arguments from growing longer and longer each time this
     // method is called.
     clearArguments();
 
-    bool ok = readProcInfo(aPid);
-    if (ok) {
-        ok |= readArguments(aPid);
-        ok |= readCurrentDir(aPid);
+    if (readProcInfo(aPid)) {
+        readArguments(aPid);
+        readCurrentDir(aPid);
     }
-    return ok;
 }
 
 void UnixProcessInfo::readUserName()
 {
     bool ok = false;
     const int uid = userId(&ok);
-    if (!ok) return;
+    if (!ok) {
+        return;
+    }
 
     struct passwd passwdStruct;
-    struct passwd* getpwResult;
-    char* getpwBuffer;
+    struct passwd *getpwResult;
+    char *getpwBuffer;
     long getpwBufferSize;
     int getpwStatus;
 
     getpwBufferSize = sysconf(_SC_GETPW_R_SIZE_MAX);
-    if (getpwBufferSize == -1)
+    if (getpwBufferSize == -1) {
         getpwBufferSize = 16384;
+    }
 
     getpwBuffer = new char[getpwBufferSize];
-    if (getpwBuffer == NULL)
+    if (getpwBuffer == NULL) {
         return;
+    }
     getpwStatus = getpwuid_r(uid, &passwdStruct, getpwBuffer, getpwBufferSize, &getpwResult);
     if ((getpwStatus == 0) && (getpwResult != NULL)) {
-        setUserName(QString(passwdStruct.pw_name));
+        setUserName(QLatin1String(passwdStruct.pw_name));
     } else {
         setUserName(QString());
         qWarning() << "getpwuid_r returned error : " << getpwStatus;
     }
     delete [] getpwBuffer;
 }
+
 #endif
 
 #if defined(Q_OS_LINUX)
 class LinuxProcessInfo : public UnixProcessInfo
 {
 public:
-    LinuxProcessInfo(int aPid, const QString& titleFormat) :
-        UnixProcessInfo(aPid, titleFormat) {
+    LinuxProcessInfo(int aPid, const QString &titleFormat) :
+        UnixProcessInfo(aPid, titleFormat)
+    {
     }
 
 protected:
-    virtual bool readCurrentDir(int aPid) {
+    bool readCurrentDir(int aPid) Q_DECL_OVERRIDE
+    {
         char path_buffer[MAXPATHLEN + 1];
         path_buffer[MAXPATHLEN] = 0;
         QByteArray procCwd = QFile::encodeName(QStringLiteral("/proc/%1/cwd").arg(aPid));
@@ -420,7 +432,8 @@ protected:
     }
 
 private:
-    virtual bool readProcInfo(int aPid) {
+    bool readProcInfo(int aPid) Q_DECL_OVERRIDE
+    {
         // indicies of various fields within the process status file which
         // contain various information about the process
         const int PARENT_PID_FIELD = 3;
@@ -442,22 +455,26 @@ private:
             QString statusLine;
             do {
                 statusLine = stream.readLine();
-                if (statusLine.startsWith(QLatin1String("Uid:")))
+                if (statusLine.startsWith(QLatin1String("Uid:"))) {
                     uidLine = statusLine;
+                }
             } while (!statusLine.isNull() && uidLine.isNull());
 
-            uidStrings << uidLine.split('\t', QString::SkipEmptyParts);
+            uidStrings << uidLine.split(QLatin1Char('\t'), QString::SkipEmptyParts);
             // Must be 5 entries: 'Uid: %d %d %d %d' and
             // uid string must be less than 5 chars (uint)
-            if (uidStrings.size() == 5)
+            if (uidStrings.size() == 5) {
                 uidString = uidStrings[1];
-            if (uidString.size() > 5)
+            }
+            if (uidString.size() > 5) {
                 uidString.clear();
+            }
 
             bool ok = false;
             const int uid = uidString.toInt(&ok);
-            if (ok)
+            if (ok) {
                 setUserId(uid);
+            }
             // This will cause constant opening of /etc/passwd
             if (userNameRequired()) {
                 readUserName();
@@ -478,7 +495,7 @@ private:
         QFile processInfo(QStringLiteral("/proc/%1/stat").arg(aPid));
         if (processInfo.open(QIODevice::ReadOnly)) {
             QTextStream stream(&processInfo);
-            const QString& data = stream.readAll();
+            const QString &data = stream.readAll();
 
             int stack = 0;
             int field = 0;
@@ -487,11 +504,11 @@ private:
             while (pos < data.count()) {
                 QChar c = data[pos];
 
-                if (c == '(') {
+                if (c == QLatin1Char('(')) {
                     stack++;
-                } else if (c == ')') {
+                } else if (c == QLatin1Char(')')) {
                     stack--;
-                } else if (stack == 0 && c == ' ') {
+                } else if (stack == 0 && c == QLatin1Char(' ')) {
                     field++;
                 } else {
                     switch (field) {
@@ -517,15 +534,18 @@ private:
         // check that data was read successfully
         bool ok = false;
         const int foregroundPid = foregroundPidString.toInt(&ok);
-        if (ok)
+        if (ok) {
             setForegroundPid(foregroundPid);
+        }
 
         const int parentPid = parentPidString.toInt(&ok);
-        if (ok)
+        if (ok) {
             setParentPid(parentPid);
+        }
 
-        if (!processNameString.isEmpty())
+        if (!processNameString.isEmpty()) {
             setName(processNameString);
+        }
 
         // update object state
         setPid(aPid);
@@ -533,7 +553,8 @@ private:
         return ok;
     }
 
-    virtual bool readArguments(int aPid) {
+    bool readArguments(int aPid) Q_DECL_OVERRIDE
+    {
         // read command-line arguments file found at /proc/<pid>/cmdline
         // the expected format is a list of strings delimited by null characters,
         // and ending in a double null character pair.
@@ -541,13 +562,14 @@ private:
         QFile argumentsFile(QStringLiteral("/proc/%1/cmdline").arg(aPid));
         if (argumentsFile.open(QIODevice::ReadOnly)) {
             QTextStream stream(&argumentsFile);
-            const QString& data = stream.readAll();
+            const QString &data = stream.readAll();
 
-            const QStringList& argList = data.split(QChar('\0'));
+            const QStringList &argList = data.split(QLatin1Char('\0'));
 
-            foreach(const QString & entry , argList) {
-                if (!entry.isEmpty())
+            foreach (const QString &entry, argList) {
+                if (!entry.isEmpty()) {
                     addArgument(entry);
+                }
             }
         } else {
             setFileError(argumentsFile.error());
@@ -561,12 +583,14 @@ private:
 class FreeBSDProcessInfo : public UnixProcessInfo
 {
 public:
-    FreeBSDProcessInfo(int aPid, const QString& titleFormat) :
-        UnixProcessInfo(aPid, titleFormat) {
+    FreeBSDProcessInfo(int aPid, const QString &titleFormat) :
+        UnixProcessInfo(aPid, titleFormat)
+    {
     }
 
 protected:
-    virtual bool readCurrentDir(int aPid) {
+    virtual bool readCurrentDir(int aPid)
+    {
 #if defined(HAVE_OS_DRAGONFLYBSD)
         char buf[PATH_MAX];
         int managementInfoBase[4];
@@ -578,24 +602,26 @@ protected:
         managementInfoBase[3] = aPid;
 
         len = sizeof(buf);
-        if (sysctl(managementInfoBase, 4, buf, &len, NULL, 0) == -1)
+        if (sysctl(managementInfoBase, 4, buf, &len, NULL, 0) == -1) {
             return false;
+        }
 
-        setCurrentDir(buf);
+        setCurrentDir(QString::fromUtf8(buf));
 
         return true;
 #else
         int numrecords;
-        struct kinfo_file* info = 0;
+        struct kinfo_file *info = 0;
 
         info = kinfo_getfile(aPid, &numrecords);
 
-        if (!info)
+        if (!info) {
             return false;
+        }
 
         for (int i = 0; i < numrecords; ++i) {
             if (info[i].kf_fd == KF_FD_TYPE_CWD) {
-                setCurrentDir(info[i].kf_path);
+                setCurrentDir(QString::fromUtf8(info[i].kf_path));
 
                 free(info);
                 return true;
@@ -608,18 +634,20 @@ protected:
     }
 
 private:
-    virtual bool readProcInfo(int aPid) {
+    virtual bool readProcInfo(int aPid)
+    {
         int managementInfoBase[4];
         size_t mibLength;
-        struct kinfo_proc* kInfoProc;
+        struct kinfo_proc *kInfoProc;
 
         managementInfoBase[0] = CTL_KERN;
         managementInfoBase[1] = KERN_PROC;
         managementInfoBase[2] = KERN_PROC_PID;
         managementInfoBase[3] = aPid;
 
-        if (sysctl(managementInfoBase, 4, NULL, &mibLength, NULL, 0) == -1)
+        if (sysctl(managementInfoBase, 4, NULL, &mibLength, NULL, 0) == -1) {
             return false;
+        }
 
         kInfoProc = new struct kinfo_proc [mibLength];
 
@@ -629,13 +657,13 @@ private:
         }
 
 #if defined(HAVE_OS_DRAGONFLYBSD)
-        setName(kInfoProc->kp_comm);
+        setName(QString::fromUtf8(kInfoProc->kp_comm));
         setPid(kInfoProc->kp_pid);
         setParentPid(kInfoProc->kp_ppid);
         setForegroundPid(kInfoProc->kp_pgid);
         setUserId(kInfoProc->kp_uid);
 #else
-        setName(kInfoProc->ki_comm);
+        setName(QString::fromUtf8(kInfoProc->ki_comm));
         setPid(kInfoProc->ki_pid);
         setParentPid(kInfoProc->ki_ppid);
         setForegroundPid(kInfoProc->ki_pgid);
@@ -648,7 +676,8 @@ private:
         return true;
     }
 
-    virtual bool readArguments(int aPid) {
+    virtual bool readArguments(int aPid)
+    {
         char args[ARG_MAX];
         int managementInfoBase[4];
         size_t len;
@@ -659,15 +688,14 @@ private:
         managementInfoBase[3] = aPid;
 
         len = sizeof(args);
-        if (sysctl(managementInfoBase, 4, args, &len, NULL, 0) == -1)
+        if (sysctl(managementInfoBase, 4, args, &len, NULL, 0) == -1) {
             return false;
+        }
 
         // len holds the length of the string
-        QString qargs = QString::fromLocal8Bit(args,len);
-        foreach (const QString& value, qargs.split('\u0000'))
-        {
-            if (!value.isEmpty())
-            {
+        QString qargs = QString::fromLocal8Bit(args, len);
+        foreach (const QString &value, qargs.split(QLatin1Char('\u0000'))) {
+            if (!value.isEmpty()) {
                 addArgument(value);
             }
         }
@@ -680,15 +708,17 @@ private:
 class OpenBSDProcessInfo : public UnixProcessInfo
 {
 public:
-    OpenBSDProcessInfo(int aPid, const QString& titleFormat) :
-        UnixProcessInfo(aPid, titleFormat) {
+    OpenBSDProcessInfo(int aPid, const QString &titleFormat) :
+        UnixProcessInfo(aPid, titleFormat)
+    {
     }
 
 protected:
-    virtual bool readCurrentDir(int aPid) {
-        char    buf[PATH_MAX];
-        int     managementInfoBase[3];
-        size_t  len;
+    virtual bool readCurrentDir(int aPid)
+    {
+        char buf[PATH_MAX];
+        int managementInfoBase[3];
+        size_t len;
 
         managementInfoBase[0] = CTL_KERN;
         managementInfoBase[1] = KERN_PROC_CWD;
@@ -700,15 +730,16 @@ protected:
             return false;
         }
 
-        setCurrentDir(buf);
+        setCurrentDir(QString::fromUtf8(buf));
         return true;
     }
 
 private:
-    virtual bool readProcInfo(int aPid) {
-        int      managementInfoBase[6];
-        size_t   mibLength;
-        struct kinfo_proc*  kInfoProc;
+    virtual bool readProcInfo(int aPid)
+    {
+        int managementInfoBase[6];
+        size_t mibLength;
+        struct kinfo_proc *kInfoProc;
 
         managementInfoBase[0] = CTL_KERN;
         managementInfoBase[1] = KERN_PROC;
@@ -722,7 +753,7 @@ private:
             return false;
         }
 
-        kInfoProc = (struct kinfo_proc*)malloc(mibLength);
+        kInfoProc = (struct kinfo_proc *)malloc(mibLength);
 
         if (::sysctl(managementInfoBase, 6, kInfoProc, &mibLength, NULL, 0) == -1) {
             qWarning() << "second sysctl() call failed with code" << errno;
@@ -741,12 +772,13 @@ private:
         return true;
     }
 
-    char** readProcArgs(int aPid, int whatMib) {
-        void*   buf = NULL;
-        void*   nbuf;
-        size_t  len = 4096;
-        int     rc = -1;
-        int     managementInfoBase[4];
+    char **readProcArgs(int aPid, int whatMib)
+    {
+        void *buf = NULL;
+        void *nbuf;
+        size_t len = 4096;
+        int rc = -1;
+        int managementInfoBase[4];
 
         managementInfoBase[0] = CTL_KERN;
         managementInfoBase[1] = KERN_PROC_ARGS;
@@ -770,18 +802,19 @@ private:
             return NULL;
         }
 
-        return (char**)buf;
+        return (char **)buf;
     }
 
-    virtual bool readArguments(int aPid) {
-        char**  argv;
+    virtual bool readArguments(int aPid)
+    {
+        char **argv;
 
         argv = readProcArgs(aPid, KERN_PROC_ARGV);
         if (argv == NULL) {
             return false;
         }
 
-        for (char** p = argv; *p != NULL; p++) {
+        for (char **p = argv; *p != NULL; p++) {
             addArgument(QString(*p));
         }
         free(argv);
@@ -789,30 +822,33 @@ private:
     }
 };
 
-#elif defined(Q_OS_OSX)
+#elif defined(Q_OS_MACOS)
 class MacProcessInfo : public UnixProcessInfo
 {
 public:
-    MacProcessInfo(int aPid, const QString& titleFormat) :
-        UnixProcessInfo(aPid, titleFormat) {
+    MacProcessInfo(int aPid, const QString &titleFormat) :
+        UnixProcessInfo(aPid, titleFormat)
+    {
     }
 
 protected:
-    virtual bool readCurrentDir(int aPid) {
+    virtual bool readCurrentDir(int aPid)
+    {
         struct proc_vnodepathinfo vpi;
         const int nb = proc_pidinfo(aPid, PROC_PIDVNODEPATHINFO, 0, &vpi, sizeof(vpi));
         if (nb == sizeof(vpi)) {
-            setCurrentDir(QString(vpi.pvi_cdir.vip_path));
+            setCurrentDir(QString::fromUtf8(vpi.pvi_cdir.vip_path));
             return true;
         }
         return false;
     }
 
 private:
-    virtual bool readProcInfo(int aPid) {
+    virtual bool readProcInfo(int aPid)
+    {
         int managementInfoBase[4];
         size_t mibLength;
-        struct kinfo_proc* kInfoProc;
+        struct kinfo_proc *kInfoProc;
         QT_STATBUF statInfo;
 
         // Find the tty device of 'pid' (Example: /dev/ttys001)
@@ -829,15 +865,17 @@ private:
                 delete [] kInfoProc;
                 return false;
             } else {
-                const QString deviceNumber = QString(devname(((&kInfoProc->kp_eproc)->e_tdev), S_IFCHR));
-                const QString fullDeviceName =  QString("/dev/") + deviceNumber.rightJustified(3, '0');
+                const QString deviceNumber = QString::fromUtf8(devname(((&kInfoProc->kp_eproc)->e_tdev), S_IFCHR));
+                const QString fullDeviceName = QStringLiteral("/dev/")
+                                               + deviceNumber.rightJustified(3, QLatin1Char('0'));
                 delete [] kInfoProc;
 
                 const QByteArray deviceName = fullDeviceName.toLatin1();
-                const char* ttyName = deviceName.data();
+                const char *ttyName = deviceName.data();
 
-                if (QT_STAT(ttyName, &statInfo) != 0)
+                if (QT_STAT(ttyName, &statInfo) != 0) {
                     return false;
+                }
 
                 // Find all processes attached to ttyName
                 managementInfoBase[0] = CTL_KERN;
@@ -846,15 +884,19 @@ private:
                 managementInfoBase[3] = statInfo.st_rdev;
 
                 mibLength = 0;
-                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), NULL, &mibLength, NULL, 0) == -1)
+                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), NULL,
+                           &mibLength, NULL, 0) == -1) {
                     return false;
+                }
 
                 kInfoProc = new struct kinfo_proc [mibLength];
-                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), kInfoProc, &mibLength, NULL, 0) == -1)
+                if (sysctl(managementInfoBase, sizeof(managementInfoBase) / sizeof(int), kInfoProc,
+                           &mibLength, NULL, 0) == -1) {
                     return false;
+                }
 
                 // The foreground program is the first one
-                setName(QString(kInfoProc->kp_proc.p_comm));
+                setName(QString::fromUtf8(kInfoProc->kp_proc.p_comm));
 
                 delete [] kInfoProc;
             }
@@ -863,7 +905,8 @@ private:
         return true;
     }
 
-    virtual bool readArguments(int aPid) {
+    virtual bool readArguments(int aPid)
+    {
         Q_UNUSED(aPid);
         return false;
     }
@@ -876,7 +919,7 @@ private:
 // although some of the structure sizes might be wrong.
 // Fortunately, the structures we actually use don't use
 // off_t, and we're safe.
-#if defined(_FILE_OFFSET_BITS) && (_FILE_OFFSET_BITS==64)
+#if defined(_FILE_OFFSET_BITS) && (_FILE_OFFSET_BITS == 64)
 #undef _FILE_OFFSET_BITS
 #endif
 #include <procfs.h>
@@ -884,14 +927,16 @@ private:
 class SolarisProcessInfo : public UnixProcessInfo
 {
 public:
-    SolarisProcessInfo(int aPid, const QString& titleFormat)
-        : UnixProcessInfo(aPid, titleFormat) {
+    SolarisProcessInfo(int aPid, const QString &titleFormat) :
+        UnixProcessInfo(aPid, titleFormat)
+    {
     }
 
 protected:
     // FIXME: This will have the same issues as BKO 251351; the Linux
     // version uses readlink.
-    virtual bool readCurrentDir(int aPid) {
+    virtual bool readCurrentDir(int aPid)
+    {
         QFileInfo info(QString("/proc/%1/path/cwd").arg(aPid));
         const bool readable = info.isReadable();
 
@@ -899,17 +944,19 @@ protected:
             setCurrentDir(info.symLinkTarget());
             return true;
         } else {
-            if (!readable)
+            if (!readable) {
                 setError(PermissionsError);
-            else
+            } else {
                 setError(UnknownError);
+            }
 
             return false;
         }
     }
 
 private:
-    virtual bool readProcInfo(int aPid) {
+    virtual bool readProcInfo(int aPid)
+    {
         QFile psinfo(QString("/proc/%1/psinfo").arg(aPid));
         if (psinfo.open(QIODevice::ReadOnly)) {
             struct psinfo info;
@@ -929,36 +976,38 @@ private:
         return true;
     }
 
-    virtual bool readArguments(int /*pid*/) {
+    virtual bool readArguments(int /*pid*/)
+    {
         // Handled in readProcInfo()
         return false;
     }
 };
 #endif
 
-SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
-    : _process(process)
-    , _user(QString())
-    , _host(QString())
-    , _port(QString())
-    , _command(QString())
+SSHProcessInfo::SSHProcessInfo(const ProcessInfo &process) :
+    _process(process),
+    _user(QString()),
+    _host(QString()),
+    _port(QString()),
+    _command(QString())
 {
     bool ok = false;
 
     // check that this is a SSH process
-    const QString& name = _process.name(&ok);
+    const QString &name = _process.name(&ok);
 
     if (!ok || name != QLatin1String("ssh")) {
-        if (!ok)
+        if (!ok) {
             qWarning() << "Could not read process info";
-        else
+        } else {
             qWarning() << "Process is not a SSH process";
+        }
 
         return;
     }
 
     // read arguments
-    const QVector<QString>& args = _process.arguments(&ok);
+    const QVector<QString> &args = _process.arguments(&ok);
 
     // SSH options
     // these are taken from the SSH manual ( accessed via 'man ssh' )
@@ -981,13 +1030,13 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
         //
         // note that we skip the argument at index 0 because that is the
         // program name ( expected to be 'ssh' in this case )
-        for (int i = 1 ; i < args.count() ; i++) {
+        for (int i = 1; i < args.count(); i++) {
             // If this one is an option ...
             // Most options together with its argument will be skipped.
-            if (args[i].startsWith('-')) {
-                const QChar optionChar = (args[i].length() > 1) ? args[i][1] : '\0';
+            if (args[i].startsWith(QLatin1Char('-'))) {
+                const QChar optionChar = (args[i].length() > 1) ? args[i][1] : QLatin1Char('\0');
                 // for example: -p2222 or -p 2222 ?
-                const bool optionArgumentCombined =  args[i].length() > 2;
+                const bool optionArgumentCombined = args[i].length() > 2;
 
                 if (noArgumentOptions.contains(optionChar)) {
                     continue;
@@ -1004,11 +1053,13 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
                     }
 
                     // support using `-l user` to specify username.
-                    if (optionChar == 'l')
+                    if (optionChar == QLatin1Char('l')) {
                         _user = argument;
+                    }
                     // support using `-p port` to specify port.
-                    else if (optionChar == 'p')
+                    else if (optionChar == QLatin1Char('p')) {
                         _port = argument;
+                    }
 
                     continue;
                 }
@@ -1021,7 +1072,7 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
                 // both a username and host are specified ( in which case they
                 // are separated by an '@' character:  username@host )
 
-                const int separatorPosition = args[i].indexOf('@');
+                const int separatorPosition = args[i].indexOf(QLatin1Char('@'));
                 if (separatorPosition != -1) {
                     // username and host specified
                     _user = args[i].left(separatorPosition);
@@ -1040,7 +1091,7 @@ SSHProcessInfo::SSHProcessInfo(const ProcessInfo& process)
                 if (_command.isEmpty()) {
                     _command = args[i];
                 } else {
-                    _command = _command + QString(' ') + args[i];
+                    _command = _command + QLatin1Char(' ') + args[i];
                 }
             }
         }
@@ -1055,34 +1106,26 @@ QString SSHProcessInfo::userName() const
 {
     return _user;
 }
+
 QString SSHProcessInfo::host() const
 {
     return _host;
 }
+
 QString SSHProcessInfo::port() const
 {
     return _port;
 }
+
 QString SSHProcessInfo::command() const
 {
     return _command;
 }
-QString SSHProcessInfo::format(const QString& input) const
+
+QString SSHProcessInfo::format(const QString &input) const
 {
     QString output(input);
 
-    // test whether host is an ip address
-    // in which case 'short host' and 'full host'
-    // markers in the input string are replaced with
-    // the full address
-    bool isIpAddress = false;
-
-    struct in_addr address;
-    if (inet_aton(_host.toLocal8Bit().constData(), &address) != 0)
-        isIpAddress = true;
-    else
-        isIpAddress = false;
-
     // search for and replace known markers
     output.replace(QLatin1String("%u"), _user);
 
@@ -1091,15 +1134,23 @@ QString SSHProcessInfo::format(const QString& input) const
     //                                 => Host Command
     // Depending on whether -l was passed to ssh (which is mostly not the
     // case due to ~/.ssh/config).
-    if (_user.isEmpty())
+    if (_user.isEmpty()) {
         output.replace(QLatin1String("%U"), QString());
-    else
-        output.replace(QLatin1String("%U"), _user + '@');
+    } else {
+        output.replace(QLatin1String("%U"), _user + QLatin1Char('@'));
+    }
 
-    if (isIpAddress)
+    // test whether host is an ip address
+    // in which case 'short host' and 'full host'
+    // markers in the input string are replaced with
+    // the full address
+    struct in_addr address;
+    const bool isIpAddress = inet_aton(_host.toLocal8Bit().constData(), &address) != 0;
+    if (isIpAddress) {
         output.replace(QLatin1String("%h"), _host);
-    else
-        output.replace(QLatin1String("%h"), _host.left(_host.indexOf('.')));
+    } else {
+        output.replace(QLatin1String("%h"), _host.left(_host.indexOf(QLatin1Char('.'))));
+    }
 
     output.replace(QLatin1String("%H"), _host);
     output.replace(QLatin1String("%c"), _command);
@@ -1107,14 +1158,14 @@ QString SSHProcessInfo::format(const QString& input) const
     return output;
 }
 
-ProcessInfo* ProcessInfo::newInstance(int aPid, const QString& titleFormat)
+ProcessInfo *ProcessInfo::newInstance(int aPid, const QString &titleFormat)
 {
     ProcessInfo *info;
 #if defined(Q_OS_LINUX)
     info = new LinuxProcessInfo(aPid, titleFormat);
 #elif defined(Q_OS_SOLARIS)
     info = new SolarisProcessInfo(aPid, titleFormat);
-#elif defined(Q_OS_OSX)
+#elif defined(Q_OS_MACOS)
     info = new MacProcessInfo(aPid, titleFormat);
 #elif defined(Q_OS_FREEBSD)
     info = new FreeBSDProcessInfo(aPid, titleFormat);
@@ -1126,4 +1177,3 @@ ProcessInfo* ProcessInfo::newInstance(int aPid, const QString& titleFormat)
     info->readProcessInfo(aPid);
     return info;
 }
-
